@@ -64,6 +64,17 @@ class CongestionSeriesPeriod(Enum):
     EIA = "eia"  #:
 
 
+class CongestionVesselsPeriod(Enum):
+    """"""
+
+    Annually = "years"  #:
+    Monthly = "months"  #:
+    Weekly = "weeks"  #:
+    Quarterly = "quarters"  #:
+    Daily = "days"  #:
+    EIA = "eia"  #:
+
+
 class CongestionSeriesSplit(Enum):
     """"""
 
@@ -472,6 +483,16 @@ class FleetUtilizationSeriesPeriod(Enum):
     Daily = "days"  #:
 
 
+class FleetUtilizationVesselsPeriod(Enum):
+    """"""
+
+    Annually = "years"  #:
+    Monthly = "months"  #:
+    Weekly = "weeks"  #:
+    Quarterly = "quarters"  #:
+    Daily = "days"  #:
+
+
 class FleetUtilizationSeriesSplit(Enum):
     """"""
 
@@ -481,6 +502,23 @@ class FleetUtilizationSeriesSplit(Enum):
     VesselType = "vesselType"  #:
     VesselTypeOil = "vesselTypeOil"  #:
     VesselTypeCpp = "vesselTypeCpp"  #:
+    SubState = "subState"  #:
+    Direction = "direction"  #:
+    CurrentSubContinents = "currentSubcontinents"  #:
+    CurrentContinents = "currentContinents"  #:
+    CurrentSubregions = "currentSubregions"  #:
+    CurrentCountries = "currentCountries"  #:
+    CurrentSeas = "currentSeas"  #:
+    PreviousTradingRegions = "previousTradingRegions"  #:
+    PreviousContinents = "previousContinents"  #:
+    PreviousSubContinents = "previousSubContinents"  #:
+    PreviousCountries = "previousCountries"  #:
+    PreviousPorts = "previousPorts"  #:
+    NextTradingRegions = "nextTradingRegions"  #:
+    NextContinents = "nextContinents"  #:
+    NextSubContinents = "nextSubContinents"  #:
+    NextCountries = "nextCountries"  #:
+    NextPorts = "nextPorts"  #:
 
 
 class FleetUtilizationSeriesUnit(Enum):
