@@ -6,6 +6,7 @@ from kpler.sdk import Platform
 from kpler.sdk.client import KplerClient
 from kpler.sdk.configuration import Configuration
 from kpler.sdk.helpers import (
+    process_bool_parameter,
     process_date_parameter,
     process_enum_parameters,
     process_list_parameter,
@@ -39,6 +40,7 @@ class BallastCapacityPortCalls(KplerClient):
         vessel_types: Optional[List[Enum]] = None,
         gte: Optional[int] = None,
         lte: Optional[int] = None,
+        with_freight_view: bool = False,
     ):
 
         """
@@ -55,6 +57,7 @@ class BallastCapacityPortCalls(KplerClient):
             vessel_types: Optional[List[Enum]] ``VesselTypesDry`` ``VesselTypesLNG`` ``VesselTypesLPG``
             gte: Optional[int] Get vessels with deadweight/capacity greater or equals to this value by default 0
             lte: Optional[int] Get vessels with deadweight/capacity lower or equals to this value by default 606550
+            with_freight_view: bool By default: with_freight_view=False. Provides access to the entire fleet's trades, irrespective of your current cargo subscription. Only available via Freight subscription.
 
         Examples:
             >>> from kpler.sdk.resources.ballast_capacity_port_calls import BallastCapacityPortCalls
@@ -85,5 +88,6 @@ class BallastCapacityPortCalls(KplerClient):
             "vesselTypes": process_enum_parameters(vessel_types),
             "gte": gte,
             "lte": lte,
+            "withFreightView": process_bool_parameter(with_freight_view),
         }
         return self._get_dataframe(self.RESOURCE_NAME, query_parameters)
